@@ -56,17 +56,17 @@ class ViewData:
 class ViewFactory:
     @staticmethod
     def createView(engine_state: EngineState):
-
         def k_to_s(k):
             if isinstance(k, Keys):
-                return f'<{k.value}>'
+                return f"<{k.value}>"
             return k
 
-
         return ViewData(
             chars=[[CharacterView(c) for c in line] for line in engine_state.buffer],
             cursor=CursorPos(
                 line=engine_state.cursor.line, column=engine_state.cursor.col
             ),
-            status="".join(map(k_to_s, engine_state.command)),
+            status=repr(
+                engine_state.command
+            ),  # "".join(map(k_to_s, engine_state.command)),
         )
